fnss.topologies.randmodels.glp_topology — FNSS 0.6.1 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.6.1 documentation »
- API Reference »
- Functions »

# fnss.topologies.randmodels.glp_topology

`glp_topology`(n, m, m0, p, beta, seed=None)

  Return a random topology using the Generalized Linear Preference (GLP) preferential attachment model.

  It differs from the extended Barabasi-Albert model in that there is link rewiring and a beta parameter is introduced to fine-tune preferential attachment.

  More precisely, the GLP topology is built as follows. First, a line topology with m0 nodes is created. Then, at each step: with probability p, add m new links between existing nodes, selected with probability:

  with probability , add a new node and attach it to m nodes of the existing topology selected with probability

  Repeat the previous step until the topology comprises n nodes in total.

  Parameters: | n : int Number of nodes m : int Number of edges to attach from a new node to existing nodes m0 : int Number of edges initially attached to the network p : float The probability that new links are added beta : float Parameter to fine-tune preferntial attachment: beta < 1 seed : int, optional Seed for random number generator (default=None).
  Returns: | G : Topology

  References

  [R22] | T. Bu and D. Towsey “On distinguishing between Internet power law topology generators”, Proceeding od the 21st IEEE INFOCOM conference. IEEE, volume 2, pages 638-647, 2002.

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.6.1 documentation »
- API Reference »
- Functions »